@@ -4,7 +4,7 @@
    Modified : Jorge Garca ( Jorge.Garcia@uv.es )
    Modified ; Mark Hurley ( debian4tux@telocity.com )
    Modified : Neil Spring ( nspring@cs.washington.edu )
- * 
+ *
  * Pop3 Email checker.
  *
  * Last Updated : Tue Nov 13 13:45:23 PST 2001
@@ -52,7 +52,7 @@ extern struct connection_state *state_for_pcu(Pop3 pc);
 
 static struct authentication_method {
 	const char *name;
-	/* callback returns the connection state pointer if successful, 
+	/* callback returns the connection state pointer if successful,
 	   NULL if failed */
 	struct connection_state  *(*auth_callback) (Pop3 pc, struct connection_state * scs, char *apop_str);
 } auth_methods[] = {
@@ -169,7 +169,7 @@ int pop3CheckMail( /*@notnull@ */ Pop3 pc)
 		/* it is not an error to receive this according to RFC 1725 */
 		/* no error should be returned */
 		pc->UnreadMsgs = pc->TotalMsgs;
-        // there's also a LIST command... not sure how to make use of it. */ 
+        // there's also a LIST command... not sure how to make use of it. */
 	} else {
 		sscanf(buf, "+OK %d", &read);
 		pc->UnreadMsgs = pc->TotalMsgs - read;
@@ -201,9 +201,9 @@ int pop3Create(Pop3 pc, const char *str)
 	int i;
 	int matchedchars;
 	/* ([^: ]+) user
-	   ([^@]+) or ([^ ]+) password 
-	   ([^: ]+) server 
-	   ([: ][0-9]+)? optional port 
+	   ([^@]+) or ([^ ]+) password
+	   ([^: ]+) server
+	   ([: ][0-9]+)? optional port
 	   ' *' gobbles trailing whitespace before authentication types.
 	   use separate regexes for old and new types to permit
 	   use of '@' in passwords
@@ -233,16 +233,7 @@ int pop3Create(Pop3 pc, const char *str)
 
 	if (strncmp("pop3s:", str, 6) == 0) {
 #ifdef HAVE_GNUTLS_GNUTLS_H
-		static int haveBeenWarned;
 		PCU.dossl = 1;
-		if (!haveBeenWarned) {
-			printf("wmbiff uses gnutls for TLS/SSL encryption support:\n"
-				   "  If you distribute software that uses gnutls, don't forget\n"
-				   "  to warn the users of your software that gnutls is at a\n"
-				   "  testing phase and may be totally insecure.\n"
-				   "\nConsider yourself warned.\n");
-			haveBeenWarned = 1;
-		}
 #else
 		printf("This copy of wmbiff was not compiled with gnutls;\n"
 			   "imaps is unavailable.  Exiting to protect your\n"
@@ -268,7 +259,7 @@ int pop3Create(Pop3 pc, const char *str)
 		pc->label[0] = '\0';
 		POP_DM(pc, DEBUG_ERROR, "Couldn't parse line %s (%d)\n"
 			   "  If this used to work, run wmbiff with the -relax option, and\n "
-			   "  send mail to wmbiff-devel@lists.sourceforge.net with the hostname\n"
+			   "  send mail to "PACKAGE_BUGREPORT" with the hostname\n"
 			   "  of your mail server.\n", str, matchedchars);
 		return -1;
 	}
@@ -408,7 +399,7 @@ static struct connection_state *authenticate_plaintext( /*@notnull@ */ Pop3 pc,
 	char buf[BUF_SIZE];
 
 	tlscomm_printf(scs, "USER %s\r\n", PCU.userName);
-	if (tlscomm_gets(buf, BUF_SIZE, scs) == NULL) {
+	if (tlscomm_gets(buf, BUF_SIZE, scs) == 0) {
 		POP_DM(pc, DEBUG_ERROR,
 			   "Error reading from server authenticating '%s@%s:%d'\n",
 			   PCU.userName, PCU.serverName, PCU.serverPort);
@@ -426,7 +417,7 @@ static struct connection_state *authenticate_plaintext( /*@notnull@ */ Pop3 pc,
 
 
 	tlscomm_printf(scs, "PASS %s\r\n", PCU.password);
-	if (tlscomm_gets(buf, BUF_SIZE, scs) == NULL) {
+	if (tlscomm_gets(buf, BUF_SIZE, scs) == 0) {
 		POP_DM(pc, DEBUG_ERROR,
 			   "Error reading from server (2) authenticating '%s@%s:%d'\n",
 			   PCU.userName, PCU.serverName, PCU.serverPort);
@@ -437,7 +428,7 @@ static struct connection_state *authenticate_plaintext( /*@notnull@ */ Pop3 pc,
         PCU.password[0] = '\0';
         ask_user_for_password(pc, 1);	/* 1=overwrite the cache */
         tlscomm_printf(scs, "PASS %s\r\n", PCU.password);
-        if (tlscomm_gets(buf, BUF_SIZE, scs) == NULL) {
+        if (tlscomm_gets(buf, BUF_SIZE, scs) == 0) {
           POP_DM(pc, DEBUG_ERROR,
                  "Error reading from server (2) authenticating '%s@%s:%d'\n",
                  PCU.userName, PCU.serverName, PCU.serverPort);
