@@ -1,3 +1,5 @@
+#define _GNU_SOURCE
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -366,7 +368,7 @@ int test_sock_connect(void)
 {
 	struct sockaddr_in addr;
 	int s = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);
-	int addrlen = sizeof(struct sockaddr_in);
+	socklen_t addrlen = sizeof(struct sockaddr_in);
 	if (s < 0) {
 		perror("socket");
 		return 1;
@@ -398,6 +400,7 @@ int print_info(UNUSED(void *state))
 	return (0);
 }
 const char *certificate_filename = NULL;
+const char *tls = "NORMAL";
 int SkipCertificateCheck = 0;
 int exists(UNUSED(const char *filename))
 {
@@ -405,14 +408,14 @@ int exists(UNUSED(const char *filename))
 }
 
 
-// void initialize_blacklist(void) { } 
+// void initialize_blacklist(void) { }
 // void tlscomm_printf(UNUSED(int x), UNUSED(const char *f), ...) { }
-// void tlscomm_expect(void) {  } 
-// void tlscomm_close() {  } 
-// int tlscomm_is_blacklisted(UNUSED(const char *x)) {  return 1; } 
-// void initialize_gnutls(void) {  } 
+// void tlscomm_expect(void) {  }
+// void tlscomm_close() {  }
+// int tlscomm_is_blacklisted(UNUSED(const char *x)) {  return 1; }
+// void initialize_gnutls(void) {  }
 // int sock_connect(UNUSED(const char *n), UNUSED(int p)) { return 1; } /* stdout */
-// void initialize_unencrypted(void) {  } 
+// void initialize_unencrypted(void) {  }
 
 int main(UNUSED(int argc), UNUSED(char *argv[]))
 {
